export default {
    "message": "Unexpected token }",
    "column": 31,
    "index": 30,
    "lineNumber": 1
}